|
Boost-Commit : |
From: jmcintyre_at_[hidden]
Date: 2007-12-05 22:41:51
Author: jared
Date: 2007-12-05 22:41:51 EST (Wed, 05 Dec 2007)
New Revision: 41773
URL: http://svn.boost.org/trac/boost/changeset/41773
Log:
Fixed gcc build issues
Text files modified:
sandbox/pinhole/boost/pinhole/property_group.hpp | 20 +++++++++++---------
sandbox/pinhole/boost/pinhole/property_info.hpp | 20 +++++++++++---------
sandbox/pinhole/libs/pinhole/build/Jamfile.v2 | 1 +
3 files changed, 23 insertions(+), 18 deletions(-)
Modified: sandbox/pinhole/boost/pinhole/property_group.hpp
==============================================================================
--- sandbox/pinhole/boost/pinhole/property_info.hpp (original)
+++ sandbox/pinhole/boost/pinhole/property_info.hpp 2007-12-05 22:41:51 EST (Wed, 05 Dec 2007)
@@ -24,10 +24,10 @@
namespace boost { namespace pinhole { namespace detail
{
- #define BOOL_TRUE "True"
- #define BOOL_FALSE "False"
- #define W_BOOL_TRUE L"True"
- #define W_BOOL_FALSE L"False"
+ #define BOOL_TRUE ("True")
+ #define BOOL_FALSE ("False")
+ #define W_BOOL_TRUE (L"True")
+ #define W_BOOL_FALSE (L"False")
///////////////////////////////////////////////////
// set_as_string Override Functors
@@ -249,14 +249,16 @@
struct property_info_base
{
public:
- property_info_base(const type_info &type) :
+ property_info_base(const std::type_info &type) :
m_type(type)
{;}
+
+ virtual ~property_info_base(){;}
- std::string m_name;
- std::string m_description;
- boost::any m_metadata;
- const type_info &m_type;
+ std::string m_name;
+ std::string m_description;
+ boost::any m_metadata;
+ const std::type_info &m_type;
virtual void set_as_string(std::string value) = 0;
virtual void set_as_wstring(std::wstring value) = 0;
Modified: sandbox/pinhole/libs/pinhole/build/Jamfile.v2
==============================================================================
--- sandbox/pinhole/libs/pinhole/build/Jamfile.v2 (original)
+++ sandbox/pinhole/libs/pinhole/build/Jamfile.v2 2007-12-05 22:41:51 EST (Wed, 05 Dec 2007)
@@ -13,6 +13,7 @@
<link>shared:<define>BOOST_ALL_DYN_LINK=1
<link>static:<define>BOOST_PINHOLE_STATIC_LINK
<library>/boost/signals//boost_signals/
+ <library>/boost/signals//boost_signals/
: usage-requirements
<link>shared:<define>BOOST_PINHOLE_DYN_LINK=1
: source-location ../src
Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk
--- sandbox/pinhole/boost/pinhole/property_group.hpp (original)
+++ sandbox/pinhole/boost/pinhole/property_group.hpp 2007-12-05 22:41:51 EST (Wed, 05 Dec 2007)
@@ -318,7 +318,7 @@
throw std::bad_cast();
}
- stringstream err;
+ std::stringstream err;
err << "The requested property \"" << property << "\" does not exist.";
throw std::out_of_range(err.str().c_str());
}
@@ -354,7 +354,7 @@
throw std::bad_cast();
}
- stringstream err;
+ std::stringstream err;
err << "The requested property \"" << property << "\" does not exist.";
throw std::out_of_range(err.str().c_str());
}
@@ -488,7 +488,7 @@
* @return The type_info structure of the property.
* @throw std::out_of_range The property requested does not exist.
*/
- const type_info& get_type_info(const std::string &property) const
+ const std::type_info& get_type_info(const std::string &property) const
{
property_collection::const_iterator itemItr = m_properties.find(property);
@@ -612,7 +612,8 @@
Setter setter,
Getter getter)
{
- internal_add_property< typename Getter::result_type >( name, description, setter, getter, boost::any());
+ boost::any no_metadata;
+ internal_add_property< typename Getter::result_type >( name, description, setter, getter, no_metadata);
}
/**
@@ -628,7 +629,8 @@
no_setter_struct setter,
Getter getter)
{
- internal_add_property< typename Getter::result_type >( name, description, NULL, getter, boost::any());
+ boost::any no_metadata;
+ internal_add_property< typename Getter::result_type >( name, description, NULL, getter, no_metadata);
}
/**
@@ -637,8 +639,8 @@
* @param description A brief description of the property for the user interface.
* @param setter The function used to set the property.
* @param getter The function used to get the property.
* @param pEditor A pointer to the editor to be used with this property, or null
* if there isn't one.
*/
template< typename Setter, typename Getter>
void add_property( std::string name,
@@ -656,8 +658,8 @@
* @param description A brief description of the property for the user interface.
* @param setter The function used to set the property.
* @param getter The function used to get the property.
* @param pEditor A pointer to the editor to be used with this property, or null
* if there isn't one.
*/
template< typename Getter>
void add_property( std::string name,
@@ -637,8 +639,8 @@
* @param setter The function used to set the property.
* @param getter The function used to get the property.
- * @param pEditor A pointer to the editor to be used with this property, or null
- * if there isn't one.
+ * @param metadata A pointer to the editor to be used with this property, or null
+ * if there isn't one.
*/
template< typename Setter, typename Getter>
@@ -656,8 +658,8 @@
* @param setter The function used to set the property.
* @param getter The function used to get the property.
- * @param pEditor A pointer to the editor to be used with this property, or null
- * if there isn't one.
+ * @param metadata A pointer to the editor to be used with this property, or null
+ * if there isn't one.
*/
template< typename Getter>
Modified: sandbox/pinhole/boost/pinhole/property_info.hpp
==============================================================================